@@ -15,8 +15,8 @@ class Generator:
     Generates the entire project.
     """
     def generate(self):
-        if not os.path.exists("wgbuild"):
-            os.mkdir("wgbuild")
+        if not os.path.exists(self.config["output_dir"]):
+            os.mkdir(self.config["output_dir"])
 
         for f in self.config["files"]:
             # This is the output file's path. It's just the input file, but
